==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/pl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarze",
    "New comment …" : "Nowy komentarz...",
    "Delete comment" : "Skasuj komentarz",
    "Post" : "Zapisz",
    "Cancel" : "Anuluj",
    "Edit comment" : "Edytuj komentarz",
    "[Deleted user]" : "[Usunięty użytkownik]",
    "No comments yet, start the conversation!" : "Brak komentarzy, zacznij konwersację!",
    "More comments …" : "Więcej komentarzy ...",
    "Save" : "Zapisz",
    "Allowed characters {count} of {max}" : "Dozwolone znaki {count} z {max}",
    "Error occurred while retrieving comment with id {id}" : "W trakcie pobierania komentarza o identyfikatorze {id} wystąpił błąd.",
    "Error occurred while updating comment with id {id}" : "W trakcie aktualizacji komentarza o identyfikatorze {id} wystąpił błąd.",
    "Error occurred while posting comment" : "Podczas wysyłania komentarza wystąpił błąd",
    "_%n unread comment_::_%n unread comments_" : ["%n nieprzeczytany komentarz","%n nieprzeczytane komentarze","%n nieprzeczytanych komentarzy","%n nieprzeczytanych komentarzy"],
    "Comment" : "Komentarz",
    "You commented" : "Skomentowałeś/-aś",
    "%1$s commented" : "%1$s skomentował/-a",
    "{author} commented" : "{author} skomentował/-a",
    "You commented on %1$s" : "Skomentowałeś/-aś w %1$s",
    "You commented on {file}" : "Skomentowałeś/-aś w {file}",
    "%1$s commented on %2$s" : "%1$s skomentował/-a %2$s",
    "{author} commented on {file}" : "{author} skomentował/-a w {file}‭",
    "<strong>Comments</strong> for files" : "<strong>Komentarze</strong> dla plików",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Zostałeś/aś wspomniany/a w \"%s\" przez użytkownika, który został usunięty",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Zostałeś/aś wspomniany/a w \"{file}\" w komentarzach przez użytkownika, który został usunięty",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s wspomniał/-a o Tobie w komentarzu “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} wspomniał/-a o Tobie w komentarzu “{file}”",
    "Unknown user" : "Nieznany użytkownik",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Pewien (obecnie) usunięty użytkownik wspomniał o Tobie w komentarzu “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Pewien (obecnie) usunięty użytkownik wspomniał o Tobie w komentarzu “{file}”"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/pl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarze",
    "Edit comment" : "Edytuj komentarz",
    "Delete comment" : "Skasuj komentarz",
    "New comment …" : "Nowy komentarz...",
    "Post" : "Zapisz",
    "Cancel" : "Anuluj",
    "[Deleted user]" : "[Usunięty użytkownik]",
    "No comments yet, start the conversation!" : "Brak komentarzy, zacznij konwersację!",
    "More comments …" : "Więcej komentarzy ...",
    "Save" : "Zapisz",
    "Allowed characters {count} of {max}" : "Dozwolone znaki {count} z {max}",
    "Error occurred while retrieving comment with ID {id}" : "Wystąpił błąd podczas pobierania komentarza o identyfikatorze {id}",
    "Error occurred while updating comment with id {id}" : "W trakcie aktualizacji komentarza o identyfikatorze {id} wystąpił błąd.",
    "Error occurred while posting comment" : "Podczas wysyłania komentarza wystąpił błąd",
    "_%n unread comment_::_%n unread comments_" : ["%n nieprzeczytany komentarz","%n nieprzeczytane komentarze","%n nieprzeczytanych komentarzy","%n nieprzeczytanych komentarzy"],
    "Comment" : "Komentarz",
    "You commented" : "Skomentowałeś/-aś",
    "%1$s commented" : "%1$s skomentował/-a",
    "{author} commented" : "{author} skomentował/-a",
    "You commented on %1$s" : "Skomentowałeś/-aś w %1$s",
    "You commented on {file}" : "Skomentowałeś/-aś w {file}",
    "%1$s commented on %2$s" : "%1$s skomentował/-a %2$s",
    "{author} commented on {file}" : "{author} skomentował/-a w {file}‭",
    "<strong>Comments</strong> for files" : "<strong>Komentarze</strong> dla plików",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Wspomniano Cię w \"%s\" przez użytkownika, który został usunięty",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Zostałeś/aś wspomniany/a w \"{file}\" w komentarzach przez użytkownika, który został usunięty",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s wspomniał/-a o Tobie w komentarzu “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} wspomniał/-a o Tobie w komentarzu “{file}”",
    "Unknown user" : "Nieznany użytkownik",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Pewien (obecnie) usunięty użytkownik wspomniał o Tobie w komentarzu “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Pewien (obecnie) usunięty użytkownik wspomniał o Tobie w komentarzu “{file}”"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
